(self.webpackChunk_N_E=self.webpackChunk_N_E||[]).push([[888],{86570:function(e,n,t){(window.__NEXT_P=window.__NEXT_P||[]).push(["/_app",function(){return t(90902)}])},90902:function(e,n,t){"use strict";t.r(n),t.d(n,{default:function(){return MyApp}});var c=t(85333),_=t(52322),i=t(97729),r=t.n(i);function MyApp(e){var n=e.Component,t=e.pageProps;return(0,_.jsxs)(_.Fragment,{children:[(0,_.jsxs)(r(),{children:[(0,_.jsx)("meta",{charSet:"utf-8"}),(0,_.jsx)("meta",{name:"viewport",content:"width=device-width, initial-scale=1, shrink-to-fit=no"}),(0,_.jsx)("meta",{name:"theme-color",content:"#000000"}),(0,_.jsx)("meta",{name:"slack-app-id",content:"A036YAU6RT7"}),(0,_.jsx)("title",{children:"Dagster"})]}),(0,_.jsx)(n,(0,c._)({},t))]})}t(2784)},97729:function(e,n,t){e.exports=t(37412)}},function(e){var __webpack_exec__=function(n){return e(e.s=n)};e.O(0,[774,179],function(){return __webpack_exec__(86570),__webpack_exec__(60222)}),_N_E=e.O()}]);
//# sourceMappingURL=_app-ea36e323d37d415e.js.map