"use strict";(self.webpackChunk_N_E=self.webpackChunk_N_E||[]).push([[318],{17131:function(n,e,t){t.d(e,{m:function(){return PageHeader}});var a=t(73235),o=t(52322);t(2784);var r=t(35505),i=t(18399),s=t(86412);function _templateObject(){var n=(0,a._)(["\n  width: 100%;\n\n  /**\n   * Blueprint breadcrumbs annoyingly have a built-in height.\n   */\n  .bp4-breadcrumbs {\n    height: auto;\n  }\n"]);return _templateObject=function(){return n},n}var PageHeader=function(n){var e=n.title,t=n.tags,a=n.right,r=n.tabs;return(0,o.jsxs)(c,{background:s.w.Gray50,padding:{top:16,left:24,right:12},border:"bottom",children:[(0,o.jsxs)(i.x,{flex:{direction:"row",justifyContent:"space-between"},padding:{bottom:16},children:[(0,o.jsxs)(i.x,{flex:{direction:"row",alignItems:"flex-start",gap:12,wrap:"wrap"},children:[e,t]}),a]}),r]})},c=(0,r.ZP)(i.x).withConfig({componentId:"sc-a1bb63a9-0"})(_templateObject())},78260:function(n,e,t){t.r(e),t.d(e,{InstanceHealthPage:function(){return InstanceHealthPage}});var a=t(73235),o=t(52322),r=t(40794),i=t(60138),s=t(18399),c=t(86412),l=t(17131),u=t(81308),d=t(2784),f=t(55237),h=t(68028),x=t(28252),m=t(42426),j=t(31761),p=t(74897),b=t(4120);function _templateObject(){var n=(0,a._)(["\n  query InstanceHealthQuery {\n    instance {\n      id\n      ...InstanceHealthFragment\n    }\n  }\n\n  ","\n"]);return _templateObject=function(){return n},n}var InstanceHealthPage=function(){(0,h.Px)(),(0,x.j)("Daemons");var n=d.useContext(p.N).pageTitle,e=(0,r.a)(g,{notifyOnNetworkStatusChange:!0}),t=(0,f.C4)(e,f.dT),a=e.loading,i=e.data;return(0,o.jsxs)(o.Fragment,{children:[(0,o.jsx)(l.m,{title:(0,o.jsx)(u.X6,{children:n}),tabs:(0,o.jsx)(b.Z,{tab:"health",refreshState:t})}),(0,o.jsx)(s.x,{padding:{vertical:16,horizontal:24},children:(0,o.jsx)(u.pm,{children:"Daemon statuses"})}),!a||(null==i?void 0:i.instance)?(null==i?void 0:i.instance)?(0,o.jsx)(m.W,{daemonStatuses:i.instance.daemonHealth.allDaemonStatuses}):null:(0,o.jsx)(s.x,{padding:{horizontal:24},style:{color:c.w.Gray400},children:"Loading…"})]})};e.default=InstanceHealthPage;var g=(0,i.Ps)(_templateObject(),j.O)},4120:function(n,e,t){t.d(e,{Z:function(){return InstanceTabs}});var a=t(52322),o=t(18399),r=t(56024),i=t(2784),s=t(20775),c=t(55237),l=t(71897),u=t(86412),d=t(29255),f=t(77334),h=i.memo(function(){var n=i.useContext(d.Z).daemons;return n?(0,a.jsx)(f.a,{content:n.content,position:"bottom",modifiers:{offset:{enabled:!0,options:{offset:[0,28]}}},children:(0,a.jsx)(l.JO,{name:"warning",color:u.w.Yellow500})}):null}),x=t(43180),m=t(63832),j=i.memo(function(n){var e=n.placeholder,t=i.useContext(d.Z).codeLocations;return t?"spinner"===t.type?(0,a.jsx)(x.u,{content:t.content,placement:"bottom",children:(0,a.jsx)(m.$,{purpose:"body-text",fillColor:u.w.Gray300})}):(0,a.jsx)(f.a,{content:t.content,position:"bottom",modifiers:{offset:{enabled:!0,options:{offset:[0,28]}}},children:(0,a.jsx)(l.JO,{name:"warning",color:u.w.Yellow500})}):e?(0,a.jsx)("div",{style:{width:"16px"}}):null}),p=t(40049),b=t(74897),g=t(78945),InstanceTabs=function(n){var e=n.refreshState,t=n.tab,l=i.useContext(b.N).healthTitle,u=(0,g._)(),d=(0,s.gV)().flagInstanceConcurrencyLimits;return(0,a.jsxs)(o.x,{flex:{direction:"row",justifyContent:"space-between",alignItems:"flex-end"},children:[(0,a.jsxs)(r.mQ,{selectedTabId:t,children:[(0,a.jsx)(p.f,{id:"locations",title:"Code locations",to:"/locations",icon:(0,a.jsx)(j,{placeholder:!1})}),(0,a.jsx)(p.f,{id:"health",title:l,to:"/health",icon:(0,a.jsx)(h,{})}),u&&d?(0,a.jsx)(p.f,{id:"concurrency",title:"Concurrency limits",to:"/concurrency"}):null,u?(0,a.jsx)(p.f,{id:"config",title:"Configuration",to:"/config"}):null]}),e?(0,a.jsx)(o.x,{padding:{bottom:8},children:(0,a.jsx)(c.xi,{refreshState:e})}):null]})}},78945:function(n,e,t){t.d(e,{_:function(){return useCanSeeConfig}});var a=t(73235),o=t(40794),r=t(60138);function _templateObject(){var n=(0,a._)(["\n  query InstanceConfigHasInfo {\n    instance {\n      id\n      hasInfo\n    }\n  }\n"]);return _templateObject=function(){return n},n}var useCanSeeConfig=function(){var n=(0,o.a)(i).data;return!!(null==n?void 0:n.instance.hasInfo)},i=(0,r.Ps)(_templateObject())}}]);
//# sourceMappingURL=318.ff05960b9dc86aad.js.map