"use strict";(self.webpackChunk_N_E=self.webpackChunk_N_E||[]).push([[651],{28888:function(n,e,t){t.d(e,{T:function(){return o}});var i=t(73235);function _templateObject(){var n=(0,i._)(["\n  height: 100%;\n  overflow-y: auto;\n  padding-bottom: 64px;\n  width: 100%;\n"]);return _templateObject=function(){return n},n}var o=t(35505).ZP.div.withConfig({componentId:"sc-2cf5acf-0"})(_templateObject())},17131:function(n,e,t){t.d(e,{m:function(){return PageHeader}});var i=t(73235),o=t(52322);t(2784);var r=t(35505),s=t(18399),c=t(86412);function _templateObject(){var n=(0,i._)(["\n  width: 100%;\n\n  /**\n   * Blueprint breadcrumbs annoyingly have a built-in height.\n   */\n  .bp4-breadcrumbs {\n    height: auto;\n  }\n"]);return _templateObject=function(){return n},n}var PageHeader=function(n){var e=n.title,t=n.tags,i=n.right,r=n.tabs;return(0,o.jsxs)(a,{background:c.w.Gray50,padding:{top:16,left:24,right:12},border:"bottom",children:[(0,o.jsxs)(s.x,{flex:{direction:"row",justifyContent:"space-between"},padding:{bottom:16},children:[(0,o.jsxs)(s.x,{flex:{direction:"row",alignItems:"flex-start",gap:12,wrap:"wrap"},children:[e,t]}),i]}),r]})},a=(0,r.ZP)(s.x).withConfig({componentId:"sc-a1bb63a9-0"})(_templateObject())},3651:function(n,e,t){t.r(e),t.d(e,{GuessJobLocationRoot:function(){return GuessJobLocationRoot}});var i=t(52322),o=t(18399),r=t(92364),s=t(28888),c=t(17131),a=t(81308),l=t(9676),d=t(54266);t(2784);var u=t(7267),h=t(47933),p=t(68028),j=t(88286),b=t(90894),x=t(51969),f=t(37160),m=t(68220),g=t(38153),GuessJobLocationRoot=function(){(0,p.Px)();var n=(0,u.UO)().jobPath,e=(0,u.$B)("/guess/(/?.*)"),t=(0,u.TH)(),v=e.params[0],w=t.search,_=(0,j.p3)(n).pipelineName,y=(0,x.vl)(),J=y.loading,O=y.options;if(J)return(0,i.jsx)(b.T,{purpose:"page"});var P=(0,m.k)(O,_);if(0===P.length)return(0,i.jsx)(o.x,{padding:{vertical:64},children:(0,i.jsx)(r.t,{icon:"no-results",title:"No matching jobs",description:(0,i.jsxs)("div",{children:[(0,i.jsx)("div",{children:(0,i.jsx)("strong",{children:_})}),"was not found in any of your definitions."]})})});if(1===P.length){var k=P[0],C=(0,x.Zj)(k),E=(0,x.E8)(k,_),G=(0,g.$U)(C,"/".concat(E?"jobs":"pipelines","/").concat(v).concat(w));return(0,i.jsx)(u.l_,{to:G})}var L=P.some(function(n){return!(0,x.E8)(n,_)});return(0,i.jsxs)(s.T,{children:[(0,i.jsx)(c.m,{title:(0,i.jsx)(a.X6,{children:_}),icon:"job",description:L?"Job / pipeline in multiple code locations":"Job in multiple code locations"}),(0,i.jsx)(o.x,{padding:{vertical:16,horizontal:24},children:(0,i.jsx)(l.b,{intent:"info",title:(0,i.jsx)("div",{children:L?(0,i.jsxs)(i.Fragment,{children:["Jobs or pipelines named ",(0,i.jsx)("strong",{children:_})," were found in multiple code locations."]}):(0,i.jsxs)(i.Fragment,{children:["Jobs named ",(0,i.jsx)("strong",{children:_})," were found in multiple code locations."]})})})}),(0,i.jsxs)(d.i,{children:[(0,i.jsx)("thead",{children:(0,i.jsxs)("tr",{children:[(0,i.jsx)("th",{children:"Code location"}),(0,i.jsx)("th",{children:L?"Job / Pipeline":"Job"})]})}),(0,i.jsx)("tbody",{children:P.map(function(n){var e=n.repository.name,t=n.repositoryLocation.name,o=(0,f.At)(e,t);return(0,i.jsxs)("tr",{children:[(0,i.jsx)("td",{style:{width:"40%"},children:o}),(0,i.jsx)("td",{children:(0,i.jsx)(h.rU,{to:(0,g.rO)(e,t,"/".concat((0,x.E8)(n,_)?"jobs":"pipelines","/").concat(_)),children:_})})]},o)})})]})]})};e.default=GuessJobLocationRoot}}]);
//# sourceMappingURL=651.0b44ba4db60b013a.js.map