"use strict";(self.webpackChunk_N_E=self.webpackChunk_N_E||[]).push([[3],{71003:function(e,o,t){t.r(o),t.d(o,{FallthroughRoot:function(){return FallthroughRoot}});var r=t(52322),n=t(18399),i=t(63832),s=t(86412),l=t(2784),a=t(7267),u=t(35157),c=t(51969),p=t(38153),FallthroughRoot=function(){return(0,r.jsx)(a.rs,{children:(0,r.jsx)(a.AW,{path:"*",children:(0,r.jsx)(FinalRedirectOrLoadingRoot,{})})})},getVisibleJobs=function(e){return e.repository.pipelines.filter(function(e){return!(0,u.pv)(e.name)})},FinalRedirectOrLoadingRoot=function(){var e=l.useContext(c.C5),o=e.allRepos,t=e.loading,u=e.locationEntries;if(t)return(0,r.jsx)(n.x,{flex:{direction:"row",justifyContent:"center"},style:{paddingTop:"100px"},children:(0,r.jsxs)(n.x,{flex:{direction:"row",alignItems:"center",gap:16},children:[(0,r.jsx)(i.$,{purpose:"section"}),(0,r.jsx)("div",{style:{color:s.w.Gray600},children:"Loading definitions…"})]})});if(u.length&&0===o.length)return(0,r.jsx)(a.l_,{to:"/locations"});var h=o.filter(function(e){return getVisibleJobs(e).length>0});if(0===h.length){var f=o.find(function(e){return e.repository.assetGroups.length});if(f)return(0,r.jsx)(a.l_,{to:(0,p.rO)(f.repository.name,f.repositoryLocation.name,"/asset-groups/".concat(f.repository.assetGroups[0].groupName))})}if(1===h.length){var g=h[0],d=getVisibleJobs(g);if(1===d.length){var x=d[0];return(0,r.jsx)(a.l_,{to:(0,p.jT)({repoName:g.repository.name,repoLocation:g.repositoryLocation.name,pipelineName:x.name,isJob:x.isJob})})}}return h.length>0?(0,r.jsx)(a.l_,{to:"/overview"}):(0,r.jsx)(a.l_,{to:"/locations"})};o.default=FallthroughRoot}}]);
//# sourceMappingURL=3.aff23930312e6b09.js.map