"use strict";(self.webpackChunk_N_E=self.webpackChunk_N_E||[]).push([[674],{17131:function(n,e,t){t.d(e,{m:function(){return PageHeader}});var o=t(73235),r=t(52322);t(2784);var i=t(35505),a=t(18399),c=t(86412);function _templateObject(){var n=(0,o._)(["\n  width: 100%;\n\n  /**\n   * Blueprint breadcrumbs annoyingly have a built-in height.\n   */\n  .bp4-breadcrumbs {\n    height: auto;\n  }\n"]);return _templateObject=function(){return n},n}var PageHeader=function(n){var e=n.title,t=n.tags,o=n.right,i=n.tabs;return(0,r.jsxs)(s,{background:c.w.Gray50,padding:{top:16,left:24,right:12},border:"bottom",children:[(0,r.jsxs)(a.x,{flex:{direction:"row",justifyContent:"space-between"},padding:{bottom:16},children:[(0,r.jsxs)(a.x,{flex:{direction:"row",alignItems:"flex-start",gap:12,wrap:"wrap"},children:[e,t]}),o]}),i]})},s=(0,i.ZP)(a.x).withConfig({componentId:"sc-a1bb63a9-0"})(_templateObject())},72674:function(n,e,t){t.r(e),t.d(e,{INSTANCE_CONFIG_QUERY:function(){return w},InstanceConfig:function(){return C}});var o=t(73235),r=t(52322);t(19757);var i=t(40794),a=t(60138),c=t(86412),s=t(18399),l=t(63832),u=t(17131),f=t(81308),d=t(94092),h=t(2784),x=t(35505),m=t(55237),g=t(68028),p=t(28252),b=t(74897),j=t(4120);function _templateObject(){var n=(0,o._)(["\n  .CodeMirror.cm-s-instance-config {\n    box-shadow: 0 1px 0 ",";\n    height: 100%;\n  }\n\n  .CodeMirror.cm-s-instance-config {\n    .config-highlight {\n      background-color: ",";\n    }\n"]);return _templateObject=function(){return n},n}function _templateObject1(){var n=(0,o._)(["\n  query InstanceConfigQuery {\n    version\n    instance {\n      id\n      info\n    }\n  }\n"]);return _templateObject1=function(){return n},n}var v=(0,x.vJ)(_templateObject(),c.w.KeylineGray,c.w.Yellow200),C=h.memo(function(){(0,g.Px)(),(0,p.j)("Configuration");var n=h.useContext(b.N).pageTitle,e=(0,i.a)(w,{notifyOnNetworkStatusChange:!0}),t=(0,m.C4)(e,m.dT),o=e.data,a=null==o?void 0:o.instance.info,c=h.useMemo(function(){return{onReady:function(n){var e=document.location.hash;if(e){var t=new RegExp("^".concat(e.slice(1),":")),o=n.getSearchCursor(t);o.findNext()&&(n.markText(o.from(),o.to(),{className:"config-highlight"}),n.scrollIntoView(o.from()))}}}},[]);return o?(0,r.jsxs)(r.Fragment,{children:[(0,r.jsx)(v,{}),(0,r.jsx)(u.m,{title:(0,r.jsx)(f.X6,{children:n}),tabs:(0,r.jsx)(j.Z,{tab:"config",refreshState:t})}),(0,r.jsx)(s.x,{padding:{vertical:16,horizontal:24},border:"bottom",children:(0,r.jsxs)(f.pm,{children:["Dagster version: ",(0,r.jsx)(f.EK,{style:{fontSize:"16px"},children:o.version})]})}),(0,r.jsx)("div",{children:(0,r.jsx)(d.u,{value:a||"",options:{readOnly:!0,lineNumbers:!0,mode:"yaml"},handlers:c,theme:["instance-config"]})})]}):(0,r.jsx)(s.x,{padding:{vertical:64},children:(0,r.jsx)(l.$,{purpose:"section"})})});e.default=C;var w=(0,a.Ps)(_templateObject1())},4120:function(n,e,t){t.d(e,{Z:function(){return InstanceTabs}});var o=t(52322),r=t(18399),i=t(56024),a=t(2784),c=t(20775),s=t(55237),l=t(71897),u=t(86412),f=t(29255),d=t(77334),h=a.memo(function(){var n=a.useContext(f.Z).daemons;return n?(0,o.jsx)(d.a,{content:n.content,position:"bottom",modifiers:{offset:{enabled:!0,options:{offset:[0,28]}}},children:(0,o.jsx)(l.JO,{name:"warning",color:u.w.Yellow500})}):null}),x=t(43180),m=t(63832),g=a.memo(function(n){var e=n.placeholder,t=a.useContext(f.Z).codeLocations;return t?"spinner"===t.type?(0,o.jsx)(x.u,{content:t.content,placement:"bottom",children:(0,o.jsx)(m.$,{purpose:"body-text",fillColor:u.w.Gray300})}):(0,o.jsx)(d.a,{content:t.content,position:"bottom",modifiers:{offset:{enabled:!0,options:{offset:[0,28]}}},children:(0,o.jsx)(l.JO,{name:"warning",color:u.w.Yellow500})}):e?(0,o.jsx)("div",{style:{width:"16px"}}):null}),p=t(40049),b=t(74897),j=t(78945),InstanceTabs=function(n){var e=n.refreshState,t=n.tab,l=a.useContext(b.N).healthTitle,u=(0,j._)(),f=(0,c.gV)().flagInstanceConcurrencyLimits;return(0,o.jsxs)(r.x,{flex:{direction:"row",justifyContent:"space-between",alignItems:"flex-end"},children:[(0,o.jsxs)(i.mQ,{selectedTabId:t,children:[(0,o.jsx)(p.f,{id:"locations",title:"Code locations",to:"/locations",icon:(0,o.jsx)(g,{placeholder:!1})}),(0,o.jsx)(p.f,{id:"health",title:l,to:"/health",icon:(0,o.jsx)(h,{})}),u&&f?(0,o.jsx)(p.f,{id:"concurrency",title:"Concurrency limits",to:"/concurrency"}):null,u?(0,o.jsx)(p.f,{id:"config",title:"Configuration",to:"/config"}):null]}),e?(0,o.jsx)(r.x,{padding:{bottom:8},children:(0,o.jsx)(s.xi,{refreshState:e})}):null]})}},78945:function(n,e,t){t.d(e,{_:function(){return useCanSeeConfig}});var o=t(73235),r=t(40794),i=t(60138);function _templateObject(){var n=(0,o._)(["\n  query InstanceConfigHasInfo {\n    instance {\n      id\n      hasInfo\n    }\n  }\n"]);return _templateObject=function(){return n},n}var useCanSeeConfig=function(){var n=(0,r.a)(a).data;return!!(null==n?void 0:n.instance.hasInfo)},a=(0,i.Ps)(_templateObject())}}]);
//# sourceMappingURL=674.2298dcca9c4dc2f9.js.map